@@ -2,6 +2,8 @@
 import argparse
 import logging
 import ConfigParser
+import os
+import pwd
 
 import procname
 import daemon
@@ -31,13 +33,27 @@ def main():
     mysql_args = dict(parser.items("mysql"))
     mon = Replmon(mysql_args)
 
+    try:
+        user = parser.get("system", "user")
+    except  (ConfigParser.NoSectionError, ConfigParser.NoSectionError):
+        uid, gid = os.getuid(), os.getgid()
+    else:
+        user_entry = pwd.getpwnam(user)
+        uid, gid = user_entry.pw_uid, user_entry.pw_gid
+
+
+    # Ensure we can touch the status file
+    mon.touch_status_file()
+    os.chown(mon.status_file, uid, gid)
+
     formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
     file_handler = logging.FileHandler(DEFAULT_LOG_FILE)
     file_handler.setFormatter(formatter)
     logger.addHandler(file_handler)
 
+
     with daemon.DaemonContext(pidfile=lockfile.pidlockfile.PIDLockFile(DEFAULT_PID_FILE),
-                              files_preserve=[file_handler.stream]):
+                              files_preserve=[file_handler.stream], uid=uid, gid=gid):
         procname.setprocname("replmon")
         # noinspection PyBroadException
         try:
